==> v2.0.1.zip: alist/README.md <==
<div align="center">
  <h3><a href="https://alist.nn.ci">Alist</a></h3>
  <p><em>A file list program that supports multiple storage, powered by gin and React.</em></p>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/release/Xhofe/alist?style=flat-square" alt="latest version"></a>
  <a href="https://github.com/Xhofe/alist/discussions"><img src="https://img.shields.io/github/discussions/Xhofe/alist?color=%23ED8936&style=flat-square" alt="discussions"></a>
  <a href="https://github.com/Xhofe/alist/actions?query=workflow%3ABuild"><img src="https://img.shields.io/github/workflow/status/Xhofe/alist/build?style=flat-square" alt="Build status"></a>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/downloads/Xhofe/alist/total?style=flat-square&color=%239F7AEA" alt="Downloads"></a>
  <a href="https://github.com/Xhofe/alist/blob/v2/LICENSE"><img src="https://img.shields.io/github/license/Xhofe/alist?style=flat-square" alt="License"></a>
  <a href="https://pay.xhofe.top">
    <img src="https://img.shields.io/badge/%24-donate-ff69b4.svg?style=flat-square" alt="donate">
  </a>
</div>


---

English | [中文](./README_cn.md)

## Features

- [x] multiple storage
  - [x] Local storage
  - [x] [aliyundrive](https://www.aliyundrive.com/)
  - [x] OneDrive / Sharepoint ([global](https://www.office.com/), [cn](https://portal.partner.microsoftonline.cn),de,us）
  - [x] [189cloud](https://cloud.189.cn)
  - [x] [GoogleDrive](https://drive.google.com/)
  - [x] [123pan](https://www.123pan.com/)
  - [x] [lanzou](https://pc.woozooo.com/)
- [x] File preview (PDF, markdown, code, plain text, ...)
- [x] Image preview in gallery mode
- [x] Video and audio preview (mp4, mp3, ...)
- [x] Office documents preview (docx, pptx, xlsx, ...)
- [x] `README.md` preview rendering
- [x] File permalink copy and direct file download
- [x] Dark mode
- [x] I18n
- [x] Protected routes (password protection and authentication) 
- [x] WebDav (readonly)
- [x] [Docker Deploy](https://hub.docker.com/r/xhofe/alist)

## Discussion

Please go to our [discussion forum](https://github.com/Xhofe/alist/discussions) for general questions, **issues are for bug reports  only.**

## Demo

Available at: <https://alist.nn.ci>.

![demo](https://inews.gtimg.com/newsapp_ls/0/14256614096/0)

## Document

<https://alist-doc.nn.ci/en/>

## License

The `AList` is open-source software licensed under the MIT license.

---

> [@Blog](https://www.nn.ci/) · [@GitHub](https://github.com/Xhofe)

==> v2.0.6.zip: alist/README.md <==
<div align="center">
  <h3><a href="https://alist.nn.ci">Alist</a></h3>
  <p><em>🗂️Another file list program that supports multiple storage, powered by Gin and React.</em></p>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/release/Xhofe/alist?style=flat-square" alt="latest version"></a>
  <a href="https://github.com/Xhofe/alist/discussions"><img src="https://img.shields.io/github/discussions/Xhofe/alist?color=%23ED8936&style=flat-square" alt="discussions"></a>
  <a href="https://github.com/Xhofe/alist/actions?query=workflow%3ABuild"><img src="https://img.shields.io/github/workflow/status/Xhofe/alist/build?style=flat-square" alt="Build status"></a>
  <a href="https://github.com/Xhofe/alist/releases"><img src="https://img.shields.io/github/downloads/Xhofe/alist/total?style=flat-square&color=%239F7AEA" alt="Downloads"></a>
  <a href="https://github.com/Xhofe/alist/blob/v2/LICENSE"><img src="https://img.shields.io/github/license/Xhofe/alist?style=flat-square" alt="License"></a>
  <a href="https://pay.xhofe.top">
    <img src="https://img.shields.io/badge/%24-donate-ff69b4.svg?style=flat-square" alt="donate">
  </a>
</div>


---

English | [中文](./README_cn.md)

## Features

- [x] Multiple storage
  - [x] Local storage
  - [x] [Aliyundrive](https://www.aliyundrive.com/)
  - [x] OneDrive / Sharepoint ([global](https://www.office.com/), [cn](https://portal.partner.microsoftonline.cn),de,us)
  - [x] [189cloud](https://cloud.189.cn)
  - [x] [GoogleDrive](https://drive.google.com/)
  - [x] [123pan](https://www.123pan.com/)
  - [x] [Lanzou](https://pc.woozooo.com/)
  - [x] [Alist](https://github.com/Xhofe/alist)
  - [x] FTP
  - [x] [PikPak](https://www.mypikpak.com/)
  - [x] [ShandianPan](https://shandianpan.com/)
  - [x] [S3](https://aws.amazon.com/s3/)
  - [x] WebDav
  - [x] Teambition([China](https://www.teambition.com/ ),[International](https://us.teambition.com/ ))
  - [x] [Mediatrack](https://www.mediatrack.cn/)
  - [x] [139yun](https://yun.139.com/) (Personal, Family)
- [x] Easy to deploy and out-of-the-box
- [x] File preview (PDF, markdown, code, plain text, ...)
- [x] Image preview in gallery mode
- [x] Video and audio preview (mp4, mp3, ...)
- [x] Office documents preview (docx, pptx, xlsx, ...)
- [x] `README.md` preview rendering
- [x] File permalink copy and direct file download
- [x] Dark mode
- [x] I18n
- [x] Protected routes (password protection and authentication) 
- [x] WebDav (see https://alist-doc.nn.ci/en/docs/webdav for details)
- [x] [Docker Deploy](https://hub.docker.com/r/xhofe/alist)
- [x] Cloudflare workers proxy
- [x] File/Folder package download
- [x] Support video list playback and subtitles(ass,srt,vtt)
- [x] Web upload(Can allow visitors to upload) and delete

## Discussion

Please go to our [discussion forum](https://github.com/Xhofe/alist/discussions) for general questions, **issues are for bug reports  only.**

## Demo

Available at: <https://alist.nn.ci>.

![demo](https://inews.gtimg.com/newsapp_ls/0/14256614096/0)

## Document

<https://alist-doc.nn.ci/en/>

## License

The `AList` is open-source software licensed under the AGPL-3.0 license.

---

> [@Blog](https://www.nn.ci/) · [@GitHub](https://github.com/Xhofe)
